function[data]=parse_otmon_log( name, tstamp )
%
% reading data is a slow process; tell the world outside what's going on:
%
fprintf('file: %s', name );
%
% define data structure:
%
data = struct('t',[],'ID', [],'v1',[],'v2',[]);

%
% read and parse file
%

fid = fopen( name, 'r' );
cnt0 = 0;
cnt1 = 0;
tline = fgetl( fid );

while ( ~feof( fid ) )
    cnt0 = cnt0 + 1;
    %
    % filter out lines coming from the boiler: these are marked with
    % Unk-DataId | Read-Ack | Write-Ack
    %
    if ( ~isempty( [ strfind( tline, 'Unk-DataId'), ...
                     strfind( tline, 'Read-Ack'), ...
                     strfind( tline, 'Write-Ack') ] ) )
        cnt1 = cnt1 + 1;
        %
        % get timestamp: format: hh:mm:ss.ssssss
        %
        tdata = sscanf( tline, '%2d:%2d:%2d.%6d', 4 );
        l_tstamp = tstamp + ...
            tdata(1) * 3600 + ...
            tdata(2) * 60 + ...
            tdata(3) + ...
            tdata(4) / 1e6;
        %
        % get actual data
        %
        ID = hex2dec( tline( 21:22 ) );
        ID_data_str = tline( 23:26 );
        
        switch (ID)
          case  { 0, 6 }
            % two flags fields
            ID_d1 = (hex2dec(ID_data_str(1:2)));
            ID_d2 = (hex2dec(ID_data_str(3:4)));
          case { 1, 9, 16, 17, 18, 24, 25, 26, 27, 28, 56, 57 }
            % f8.8
            if (ID == 24 )
                % fprintf('ID: %3d, str: %s', ID, ID_data_str );
            end;
            msb = double(hex2dec(ID_data_str(1:2)));
            if (msb>=128)
                msb = -(256-msb);
            end;
            lsb = double(hex2dec(ID_data_str(3:4)))/256;
            ID_d1 = msb + lsb;
            if (ID == 24 )
                %fprintf(', ID_d1 = %f\n', ID_d1);
            end;
            ID_d2 = 0;
          case { 2, 3, 5 }
            % flags field and unsigned char
            ID_d1 = hex2dec(ID_data_str(1:2));
            ID_d2 = hex2dec(ID_data_str(3:4));
           
          case { 35, 48, 127 }
            % two unsigned characters
            ID_d1 = hex2dec(ID_data_str(1:2));
            ID_d2 = hex2dec(ID_data_str(3:4));
            
          case { 15, 73, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123 }
            % unsigned short
            ID_d1 = hex2dec(ID_data_str(1:4));
            ID_d2 = 0;
          otherwise
            fprintf('unknown ID found: %d, time = %17.6f\n', ID,l_tstamp  );
        end;
        data(cnt1).t  = double(l_tstamp);
        data(cnt1).ID = ID;
        data(cnt1).v1 = double(ID_d1);
        data(cnt1).v2 = double(ID_d2);
    end;
    
    tline = fgetl( fid );
end;
fclose( fid );
fprintf(', %d lines read, %d lines parsed.\n', cnt0, cnt1 );

